@@ -2,7 +2,16 @@ import json
 import sys
 import random
 import requests
-from utils import Singleton
+
+class Singleton(type):
+    _instances = {}
+
+    def __call__(cls, *args, **kwargs):
+        if cls not in cls._instances:
+            cls._instances[cls] = super(Singleton, cls)\
+                .__call__(*args, **kwargs)
+        return cls._instances[cls]
+
 
 class Slack(metaclass=Singleton):
     def __init__(self, web_hook):
