@@ -4,7 +4,16 @@ Module for log all the messages in the same format
 import sys
 import logging
 import bunyan
-from utils import Singleton
+
+class Singleton(type):
+    _instances = {}
+
+    def __call__(cls, *args, **kwargs):
+        if cls not in cls._instances:
+            cls._instances[cls] = super(Singleton, cls)\
+                .__call__(*args, **kwargs)
+        return cls._instances[cls]
+
 
 class Logger(metaclass=Singleton):
     """
